@@ -2,6 +2,7 @@ package dasel
 
 import (
 	"fmt"
+	"github.com/tomwright/dasel/v2/dencoding"
 	"reflect"
 )
 
@@ -18,6 +19,10 @@ var AllFunc = BasicFunction{
 
 		for _, val := range input {
 			switch val.Kind() {
+			case reflect.String:
+				for _, r := range val.String() {
+					res = append(res, ValueOf(string(r)))
+				}
 			case reflect.Slice, reflect.Array:
 				for i := 0; i < val.Len(); i++ {
 					res = append(res, val.Index(i))
@@ -27,7 +32,13 @@ var AllFunc = BasicFunction{
 					res = append(res, val.MapIndex(key))
 				}
 			default:
-				return nil, fmt.Errorf("cannot use all selector on non slice/array/map types")
+				if val.IsDencodingMap() {
+					for _, k := range val.Interface().(*dencoding.Map).Keys() {
+						res = append(res, val.dencodingMapIndex(ValueOf(k)))
+					}
+				} else {
+					return nil, fmt.Errorf("cannot use all selector on non slice/array/map types")
+				}
 			}
 		}
 
