@@ -26,6 +26,7 @@ func selectFlags(cmd *cobra.Command) {
 	cmd.Flags().Bool("pretty", true, "Pretty print the output.")
 	cmd.Flags().Bool("colour", false, "Print colourised output.")
 	cmd.Flags().Bool("escape-html", false, "Escape HTML tags when writing output.")
+	cmd.Flags().Int("indent", 2, "The indention level when writing files.")
 	cmd.Flags().String("csv-comma", ",", "Comma separator to use when working with csv files.")
 	cmd.Flags().String("csv-write-comma", "", "Comma separator used when writing csv files. Overrides csv-comma when writing.")
 	cmd.Flags().String("csv-comment", "", "Comma separator used when reading csv files.")
@@ -42,6 +43,7 @@ func selectRunE(cmd *cobra.Command, args []string) error {
 	prettyPrintFlag, _ := cmd.Flags().GetBool("pretty")
 	colourFlag, _ := cmd.Flags().GetBool("colour")
 	escapeHTMLFlag, _ := cmd.Flags().GetBool("escape-html")
+	indent, _ := cmd.Flags().GetInt("indent")
 	csvComma, _ := cmd.Flags().GetString("csv-comma")
 	csvWriteComma, _ := cmd.Flags().GetString("csv-write-comma")
 	csvComment, _ := cmd.Flags().GetString("csv-comment")
@@ -62,6 +64,7 @@ func selectRunE(cmd *cobra.Command, args []string) error {
 			PrettyPrint: prettyPrintFlag,
 			Colourise:   colourFlag,
 			EscapeHTML:  escapeHTMLFlag,
+			Indent:      indent,
 			CsvComma:    csvWriteComma,
 			CsvUseCRLF:  csvCRLF,
 		},
